@@ -26,7 +26,7 @@
 # SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #
 from mo_parsing import whitespaces
-from mo_parsing.core import ParserElement, _PendingSkip
+from mo_parsing.core import ParserElement, _PendingSkip, set_parser_names
 from mo_parsing.enhancement import *
 from mo_parsing.exceptions import (
     ParseException,
@@ -40,7 +40,13 @@ from mo_parsing.whitespaces import Whitespace
 whitespaces.NO_WHITESPACE = Whitespace("").use()
 whitespaces.STANDARD_WHITESPACE = Whitespace().use()
 
-from mo_parsing.infix import LEFT_ASSOC, RIGHT_ASSOC, infix_notation, delimited_list, one_of
+from mo_parsing.infix import (
+    LEFT_ASSOC,
+    RIGHT_ASSOC,
+    infix_notation,
+    delimited_list,
+    one_of,
+)
 from mo_parsing.regex import Regex
 from mo_parsing.tokens import *
 
@@ -85,6 +91,7 @@ __all__ = [
     "RIGHT_ASSOC",
     "RecursiveGrammarException",
     "Regex",
+    "set_parser_names",
     "SkipTo",
     "StringEnd",
     "StringStart",
