@@ -275,7 +275,7 @@ class Many(ParseEnhancement):
                             )
                 result = self.expr._parse(string, index, do_actions)
                 end = result.end
-                if result:
+                if result.end - result.start:
                     acc.append(result)
                     failures.extend(result.failures)
                     count += 1
